/************************************************************************
*                                                                       *
*                                                                       *
*                                '                                      *
*                               \\  /'\\                                *
*                               || || ||                                *
*                               || || ||                                *
*                               \\ \\,/                                 *
*                                                                       *
*                                                                       *
*                                                                       *
*                Copyright (c) 1993/94 Jan van der Steen                *
*              Centre for Mathematics and Computer Science              *
*                      Amsterdam, the Netherlands                       *
*                                                                       *
*-----------------------------------------------------------------------*
*   You are not allowed to use this software in commercial software.    *
*   You are allowed to use this software in free software under the     *
*   condition that you maintain this integral message in the source.    *
*-----------------------------------------------------------------------*
* File    : %M%                                                         *
* Purpose : ___________________________________________________________ *
* Version : %I%                                                         *
* Modified: %G% %U%                                                     *
* Author  : Jan van der Steen (jansteen@cwi.nl)                         *
************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>

#include "io.h"

/*
 * Adjust the output to IGS standards?
 */
#ifndef IGS
#define IGS 0
#endif

static void do_error (int kind, char *message);

void
msg(int kind, char *fmt, ...)
{
    va_list ap;
    char msgbuffer[1024];

    va_start(ap, fmt);
    vsprintf(msgbuffer, fmt, ap);
    va_end(ap);

    do_error(kind, msgbuffer);
}

static void
do_error(kind, message)
/*
 * We distinguish four kind of messages:
 *
 *	MSG_USR_OUT	Normal output to the user
 *	MSG_USR_ERR	Error message to the user
 *	MSG_SYS_OUT	Diagnostic output for the system
 *	MSG_SYS_ERR	Error message for the system
 */
int	kind;
char *	message;
{
    switch (kind) {
	case MSG_USR_OUT :
#if IGS
		SENDMESSAGE(message, player, type);
#else
		fprintf(stdout, "%s", message);
#endif
		break;
	case MSG_USR_ERR :
#if IGS
		SENDMESSAGE(message, player, type);
#else
		fprintf(stderr, "%s", message);
#endif
		break;
	case MSG_SYS_OUT :
	case MSG_SYS_ERR :
#if IGS
#ifdef DEBUG
		fprintf(stderr, message);
#endif
#else
		fprintf(stderr, message);
#endif
		break;
	default		 :
#if IGS
#ifdef DEBUG
		fprintf(stderr,
			"Unexpected message type (%d) in do_error()\n",
			kind);
#endif
#else
		fprintf(stderr,
			"Unexpected message type (%d) in do_error()\n",
			kind);
#endif
		break;
    }
}
